﻿// Copyright (c) Pookthetook. All rights reserved. See License.md in the project root for license information.

using System;
using System.Reflection;
using System.Windows.Media;

using Styx.Common;
using Styx.Plugins;

namespace Pookthetook.Grounded
{
    /// <summary>
    /// Grounded plugin.
    /// </summary>
    public class Grounded : HBPlugin
    {
        /// <summary>
        /// The author of this plugin.
        /// </summary>
        /// <value>
        /// The author.
        /// </value>
        public override string Author
        {
            get { return "Pookthetook"; }
        }

        /// <summary>
        /// The name of this plugin.
        /// </summary>
        /// <value>
        /// The name.
        /// </value>
        public override string Name
        {
            get { return "Grounded"; }
        }

        /// <summary>
        /// The version of the plugin.
        /// </summary>
        /// <value>
        /// The version.
        /// </value>
        public override Version Version
        {
            get { return Assembly.GetExecutingAssembly().GetName().Version; }
        }

        /// <summary>
        /// Called when this plugin is disabled, and also on shut down of the bot.
        /// </summary>
        /// <remarks>
        /// <para>
        /// This function is called from the thread that disabled the plugin, which is typically the GUI thread.
        /// </para>
        /// <para>
        /// It is not a guarantee that WoW is running when this function is called. See <see cref="P:Styx.StyxWoW.WowExited"/>.
        /// </para>
        /// </remarks>
        public override void OnDisable()
        {
            Logging.Write(Colors.CadetBlue, "[Grounded]: The bot must be restarted for wings to be restored.");
        }

        /// <summary>
        /// Called when this plugin is enabled.
        /// </summary>
        /// <remarks>
        /// <para>
        /// This function is called from the thread that enabled the plugin, which is typically the GUI thread.
        /// </para>
        /// </remarks>
        public override void OnEnable()
        {
            WingClipper.ClipWings();
        }

        /// <summary>
        /// Called every time the engine pulses.
        /// </summary>
        /// <remarks>
        /// This is called from the bot thread.
        /// </remarks>
        public override void Pulse()
        {
        }
    }
}