﻿// Copyright (c) Pookthetook. All rights reserved. See License.md in the project root for license information.

using System.Collections.Generic;
using System.Linq;

using Styx;
using Styx.CommonBot;
using Styx.WoWInternals;

namespace Pookthetook.Grounded
{
    /// <summary>
    /// Class containing new versions of <see cref="Styx.Pathing.Flightor"/> members.
    /// </summary>
    public static class NewFlightor
    {
        /// <summary>
        /// Gets a value indicating whether the player can fly.
        /// <para>
        /// To be used as an override for <see cref="Styx.Pathing.Flightor.CanFly"/>.
        /// Does not use flying in Draenor even if the player is capable of it.
        /// </para>
        /// </summary>
        public static bool CanFly
        {
            get
            {
                var mapIds = new List<int> { 0, 1, 530, 571, 646, 870, 609 };
                if (!StyxWoW.WorldScene.WorldMap.GetMaps().Where(m => m.IsActive).ToList().Any(p => mapIds.Contains(p.MapID))) return false;

                var activeMover = WoWMovement.ActiveMover;
                return activeMover != null
                       && (activeMover.MovementInfo.CanFly
                           || activeMover.IsMe && !StyxWoW.Me.InVehicle
                           && (SpellManager.HasSpell("Expert Riding") || SpellManager.HasSpell("Artisan Riding") || SpellManager.HasSpell("Master Riding"))
                           && (Lua.GetReturnVal<bool>("return IsFlyableArea()", 0) && (Mount.FlyingMounts.Count != 0 || StyxWoW.Me.Class == WoWClass.Druid)
                               && ((StyxWoW.Me.Level >= 60 || StyxWoW.Me.Class == WoWClass.Druid) && (StyxWoW.Me.Level >= 58 || StyxWoW.Me.Class != WoWClass.Druid))));
            }
        }
    }
}