﻿// Copyright (c) Pookthetook. All rights reserved. See License.md in the project root for license information.

using System;
using System.Reflection;
using System.Windows.Media;

using Styx.Common;
using Styx.Pathing;

namespace Pookthetook.Grounded
{
    /// <summary>
    /// Disallows flying in certain areas.
    /// </summary>
    internal static class WingClipper
    {
        /// <summary>
        /// Replaces the <see cref="Flightor.CanFly"/> property to disable flight.
        /// </summary>
        public static void ClipWings()
        {
            try
            {
                var currentCanFly = typeof(Flightor).GetProperty("CanFly", BindingFlags.Public | BindingFlags.Static).GetMethod;
                var newCanFly = typeof(NewFlightor).GetProperty("CanFly", BindingFlags.Public | BindingFlags.Static).GetMethod;
                ReplaceMethod(currentCanFly, newCanFly);

                Logging.Write(Colors.CadetBlue, "[Grounded]: Wings clipped.");
            }
            catch (Exception ex)
            {
                Logging.Write(Colors.Red, "[Grounded]: Could not clip wings.\n{0}", ex.Message);
            }
        }

        private static unsafe void ReplaceMethod(MethodInfo oldMethod, MethodInfo newMethod)
        {
            var oldMethodAddress = new IntPtr((int*)oldMethod.MethodHandle.Value.ToPointer() + 2);
            var destination = (uint*)oldMethodAddress.ToPointer();
            *destination = (uint)newMethod.MethodHandle.GetFunctionPointer().ToInt32();
        }
    }
}